@@ -41,9 +41,7 @@ def get_triplets_powering_knobs(madx: Madx, ip: int) -> Dict[str, float]:
     return {right_knob: madx.globals[right_knob], left_knob: madx.globals[left_knob]}
 
 
-def get_independent_quadrupoles_powering_knobs(
-    madx: Madx, quad_numbers: Sequence[int], ip: int, beam: int
-) -> Dict[str, float]:
+def get_independent_quadrupoles_powering_knobs(madx: Madx, quad_numbers: Sequence[int], ip: int, beam: int) -> Dict[str, float]:
     """
     Returns the powering knob values for the provided quadrupoles around the given IP.
 
@@ -234,17 +232,6 @@ def prepare_output_directories(outputdir: Path) -> Tuple[Dict[str, Path], Dict[s
         {"main": beam2_dir, "tfs": beam2_tfs_dir, "knobs": beam2_knobs_dir, "plots": beam2_plots_dir},
     )
 
-    # return (
-    #     beam1_dir,
-    #     beam1_tfs_dir,
-    #     beam1_knobs_dir,
-    #     beam1_plots_dir,
-    #     beam2_dir,
-    #     beam2_tfs_dir,
-    #     beam2_knobs_dir,
-    #     beam2_plots_dir,
-    # )
-
 
 def write_knob_powering(file_path: Path, knob_dict: Dict[str, float]) -> None:
     """
@@ -285,3 +272,24 @@ def load_knobs_file(filepath: Path) -> Dict[str, float]:
         knob_value = float(shlex.split(line)[-1][:-1])  # last element is value, and we ignore the ;
         knob_dict[knob_name] = knob_value
     return knob_dict
+
+
+def load_knobs_change_file(filepath: Path) -> Dict[str, float]:
+    """
+    Loads the knob values from the file they are written in by `~.write_knob_powering`.
+
+    Args:
+        filepath (Path): `~pathlib.Path` object to the file with the saved knob values.
+
+    Returns:
+        A `~dict` of knob names and their values, in absolute powering.
+    """
+    logger.debug(f"Loading knob values from '{filepath.absolute()}'.")
+    knob_dict = {}
+    for line in filepath.read_text().splitlines():
+        knob_name = shlex.split(line)[0]
+        sign, delta = shlex.split(line)[-2:]
+        delta = delta.replace(";", "")  # we ignore the ; at the end of the line
+        knob_value = float(sign + delta)  # last element is value, and we ignore the ;
+        knob_dict[knob_name] = knob_value
+    return knob_dict
